nbqol.env
=========

.. automodule:: nbqol.env

   
   .. rubric:: Functions

   .. autosummary::
   
      add_git_root_to_sys_path
      diffpath
      is_running_in_jupyter
      is_running_in_vscode
      is_running_in_vscode_jupyter
      notebook_path
      path_to_git_root
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   detect
   pathutils
